@@ -1,6 +1,6 @@
 # -*- python -*-
 
-# Copyright (C) 1998-2005 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2006 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -14,10 +14,10 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
+# USA.
 
-"""Distributed default settings for significant Mailman config variables.
-"""
+"""Distributed default settings for significant Mailman config variables."""
 
 # NEVER make site configuration changes to this file.  ALWAYS make them in
 # mm_cfg.py instead, in the designated area.  See the comments in that file
@@ -260,10 +260,13 @@ PRIVATE_EXTERNAL_ARCHIVER = No
 # should modify the Message object as necessary.
 ARCHIVE_SCRUBBER = 'Mailman.Handlers.Scrubber'
 
-# Mailman.Handlers.Scrubber uses attachment's filename as is.
-# If you don't like this (extremely long mime-encoded filename) then set
-# this True.
-SCRUBBER_DONT_USE_ATTACHMENT_FILENAME = False
+# Control parameter whether Mailman.Handlers.Scrubber should use message
+# attachment's filename as is indicated by the filename parameter or use
+# 'attachement-xxx' instead.  The default is set True because the applications
+# on PC and Mac begin to use longer non-ascii filenames.  Historically, it
+# was set False in 2.1.6 for backward compatiblity but it was reset to True
+# for safer operation in mailman-2.1.7.
+SCRUBBER_DONT_USE_ATTACHMENT_FILENAME = True
 
 # Use of attachment filename extension per se is may be dangerous because
 # virus fakes it. You can set this True if you filter the attachment by
@@ -488,6 +491,7 @@ GLOBAL_PIPELINE = [
     'CalcRecips',
     'AvoidDuplicates',
     'Cleanse',
+    'CleanseDKIM',
     'CookHeaders',
     # And now we send the message to the digest mbox file, and to the arch and
     # news queues.  Runners will provide further processing of the message,
@@ -506,6 +510,7 @@ GLOBAL_PIPELINE = [
 OWNER_PIPELINE = [
     'SpamDetect',
     'Replybot',
+    'CleanseDKIM',
     'OwnerRecips',
     'ToOutgoing',
     ]
@@ -652,8 +657,12 @@ VERP_DELIVERY_INTERVAL = 0
 VERP_CONFIRM_FORMAT = '%(addr)s+%(cookie)s'
 
 # This is analogous to VERP_REGEXP, but for splitting apart the
-# VERP_CONFIRM_FORMAT.
-VERP_CONFIRM_REGEXP = r'^(?P<addr>[^+]+?)\+(?P<cookie>[^@]+)@.*$'
+# VERP_CONFIRM_FORMAT.  MUAs have been observed that mung
+# From: local_part@host
+# into
+# To: "local_part" <local_part@host>
+# when replying, so we skip everything up to '<' if any.
+VERP_CONFIRM_REGEXP = r'^(.*<)?(?P<addr>[^+]+?)\+(?P<cookie>[^@]+)@.*$'
 
 # Set this to Yes to enable VERP-like (more user friendly) confirmations
 VERP_CONFIRMATIONS = No
@@ -1000,6 +1009,9 @@ DEFAULT_FILTER_FILENAME_EXTENSIONS = [
 # passed through. Format is the same as DEFAULT_FILTER_FILENAME_EXTENSIONS.
 DEFAULT_PASS_FILENAME_EXTENSIONS = []
 
+# Replace multipart/alternative with its first alternative.
+DEFAULT_COLLAPSE_ALTERNATIVES = Yes
+
 # Whether text/html should be converted to text/plain after content filtering
 # is performed.  Conversion is done according to HTML_TO_PLAIN_TEXT_COMMAND
 DEFAULT_CONVERT_HTML_TO_PLAINTEXT = Yes
@@ -1179,7 +1191,7 @@ PENDINGDB_LOCK_DEBUGGING = Off
 # These directories are used to find various important files in the Mailman
 # installation.  PREFIX and EXEC_PREFIX are set by configure and should point
 # to the installation directory of the Mailman package.
-PYTHON          = '/usr/local/bin/python2.3'
+PYTHON          = '/usr/local/bin/python2.5'
 PREFIX          = '/usr/local/lib/mailman'
 EXEC_PREFIX     = '${prefix}'
 VAR_PREFIX      = '/var/spool/mailman'
@@ -1324,6 +1336,7 @@ LC_DESCRIPTIONS = {}
 def add_language(code, description, charset):
     LC_DESCRIPTIONS[code] = (description, charset)
 
+add_language('ar',    _('Arabic'),              'utf-8')
 add_language('ca',    _('Catalan'),             'iso-8859-1')
 add_language('cs',    _('Czech'),               'iso-8859-2')
 add_language('da',    _('Danish'),              'iso-8859-1')
@@ -1336,6 +1349,7 @@ add_language('fi',    _('Finnish'),             'iso-8859-1')
 add_language('fr',    _('French'),              'iso-8859-1')
 add_language('hr',    _('Croatian'),            'iso-8859-2')
 add_language('hu',    _('Hungarian'),           'iso-8859-2')
+add_language('ia',    _('Interlingua'),         'iso-8859-15')
 add_language('it',    _('Italian'),             'iso-8859-1')
 add_language('ja',    _('Japanese'),            'euc-jp')
 add_language('ko',    _('Korean'),              'euc-kr')
@@ -1352,6 +1366,7 @@ add_language('sl',    _('Slovenian'),           'iso-8859-2')
 add_language('sv',    _('Swedish'),             'iso-8859-1')
 add_language('tr',    _('Turkish'),             'iso-8859-9')
 add_language('uk',    _('Ukrainian'),           'utf-8')
+add_language('vi',    _('Vietnamese'),          'utf-8')
 add_language('zh_CN', _('Chinese (China)'),     'utf-8')
 add_language('zh_TW', _('Chinese (Taiwan)'),    'utf-8')
 
